%define ALD_Ver		1.2.1

Name:         sqlite

License:      Public Domain
Summary:      SQLite: An Embeddable SQL Database Engine
Group:        Development/Libraries
Version:      3071502
Release:      1

Source: %{name}-autoconf-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/net
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target_  %{nil}
%define target %{_build}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
This package contains the SQLite library
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel
These libraries are needed to compile C code.

#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-autoconf-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fPIC -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
%if %{_target_cpu} == "armv7l"
OPTFLAGS="-O2 -fPIC -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%else
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif
%endif

%if %{_os} == "mingw"
CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS=" "
%else
CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -std=gnu99"
GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=`case $GCC_VER_STR in \
 4.[56789].*) echo -static-libgcc ;; \
 esac`
LDFLAGS="$LDFLAGS -Wl,--gc-sections"
%endif

CFLAGS="$CFLAGS -DSQLITE_TEMP_STORE=3 \
	-DSQLITE_OMIT_LOAD_EXTENSION=1 \
	-DHAVE_POSIX_FALLOCATE=0"

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--disable-static \
	--disable-libtool-lock \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
rm $RPM_BUILD_ROOT%{_libdir}/*.la

mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
cp sqlite3.1 $RPM_BUILD_ROOT%{_mandir}/man1/

cp README $RPM_BUILD_ROOT%{docdir}/

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%if %{BUILD_LOCAL_CROSS}
rm -r $RPM_BUILD_ROOT%{cross_bindir}
rm -r $RPM_BUILD_ROOT%{cross_mandir}
%endif #BUILD_LOCAL_CROSS
%endif #_CROSS

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if (%{_os} == "mingw")
  rm %{name}-$SE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%Files
%{_prefix}

%if %{BUILD_LOCAL_CROSS}
%Files %{TO_ARCH}
%{csysdir}
%endif #!BUILD_LOCAL_CROSS
%else  #mingw

%Files
%{_bindir}
%{_libdir}/*.so.*
%{_mandir}
%{docdir}

%Files devel
%{_includedir}
%{_libdir}/*.so
%{_libdir}/pkgconfig

# ------------------- Cross Files ------------------------------------
%if %{BUILD_LOCAL_CROSS}

%Files %{TO_ARCH}
%{cross_libdir}/*.so.*
%{cross_libdir}/*.so
%{cross_libdir}/pkgconfig
%{cross_includedir}
%{cross_docdir}

%endif #!BUILD_LOCAL_CROSS
%endif #!mingw
